==> aiochroma-0.2.0.tar.gz: aiochroma-0.2.0/README.md <==
[![GitHub Release](https://img.shields.io/github/release/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=blue)](https://github.com/Vaskivskyi/aiochroma/releases) [![License](https://img.shields.io/github/license/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)](LICENSE)<br/>
![Downloads](https://img.shields.io/pypi/dm/aiochroma?style=for-the-badge&color=blue) ![Commit activity](https://img.shields.io/github/commit-activity/m/vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://asusrouter.vaskivskyi.com/BuyMeACoffee.png" alt="Buy Me A Coffee" style="height: 28px !important;" align="right" /></a>

## AIOChroma

**AIOChroma** is an API wrapper for communication with Razer Chroma devices.

Up till now, it is mostly used for the [custom Chroma integration for Home Assistant](https://github.com/Vaskivskyi/ha-chroma). But you are welcome to use it for your purposes, as well as suggest new features which you would like to use.

A short presentation of the features can be found in this [YouTube video](https://www.youtube.com/watch?v=ytdS9JUWSb4).

## Installation

Installation of the latest release is available from PyPI:

```
pip install aiochroma
```

## Usage

This section is still under development.

## Supported devices

This list provides only the models tested by me or other users.

Some of the devices might be in the group which you would not expect. This is not related to the integration but to the Chroma SDK.

<table>

<tr><th>Group</th><th>Devices</th></tr>

<tr><td>Chromalink</td><td>

`Chroma Addressable RGB Controller` (<a href="https://amzn.to/3WyMNzb" rel="nofollow sponsored" target="_blank">link*</a>)<br />
Mousepads: `Goliathus Extended Chroma` (<a href="https://amzn.to/3Gudkbl" rel="nofollow sponsored" target="_blank">link</a>)<br/>
Services: `AuraConnect`

</td></tr>

<tr><td>Headset</td><td>

`Kraken 7.1 V2` (<a href="https://amzn.to/3G78AqG" rel="nofollow sponsored" target="_blank">link</a>), `Kraken X USB` (<a href="https://amzn.to/3Z1QUWk" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Keyboard</td><td>

`BlackWidow Chroma` (<a href="https://amzn.to/3hWc7QU" rel="nofollow sponsored" target="_blank">link</a>), `BlackWidow Elite`(<a href="https://amzn.to/3NFzSJy" rel="nofollow sponsored" target="_blank">link</a>), `BlackWidow V3 Pro` (<a href="https://amzn.to/3i58M1Q" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Cynosa Chroma` (<a href="https://amzn.to/3VFbI2S" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Huntsman Elite` (<a href="https://amzn.to/3C8fhb1" rel="nofollow sponsored" target="_blank">link</a>), `Huntsman V2 Analog` (<a href="https://amzn.to/3YbKink" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Keypad</td><td>

`Tartarus V2` (<a href="https://amzn.to/3RUYVuq" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Mouse</td><td>

`Basilisk` (<a href="https://amzn.to/3jDzfE4" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`DeathAdder V2 Pro` (<a href="https://amzn.to/3jEJBnl" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Mamba Tournament Edition` (<a href="https://amzn.to/3WCAguA" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Viper Ultimate` (<a href="https://amzn.to/3G5kRMu" rel="nofollow sponsored" target="_blank">link</a>) (+ `Mouse Dock`) (<a href="https://amzn.to/3YXCyWN" rel="nofollow sponsored" target="_blank">link</a>)
</td></tr>

<tr><td>Mousepad</td><td>

`Base Station V2 Chroma` (<a href="https://amzn.to/3x7NxjS" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Firefly V2` (<a href="https://amzn.to/3FYiAm0" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Mouse Bungee V3 Chroma` (<a href="https://amzn.to/3ImsEbg" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

</table>
* As an Amazon Associate I earn from qualifying purchases. Not like I ever got anything yet (:

## Support the development

This library is a free-time project. If you like it, you can support me by buying a coffee.

<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://asusrouter.vaskivskyi.com/BuyMeACoffee.png" alt="Buy Me A Coffee" style="height: 60px !important;"></a>

==> aiochroma-0.3.0.tar.gz: aiochroma-0.3.0/README.md <==
[![GitHub Release](https://img.shields.io/github/release/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=blue)](https://github.com/Vaskivskyi/aiochroma/releases) [![License](https://img.shields.io/github/license/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)](LICENSE)<br/>
![Downloads](https://img.shields.io/pypi/dm/aiochroma?style=for-the-badge&color=blue) ![Commit activity](https://img.shields.io/github/commit-activity/m/vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://asusrouter.vaskivskyi.com/BuyMeACoffee.png" alt="Buy Me A Coffee" style="height: 28px !important;" align="right" /></a>

## AIOChroma

> [!TIP]
> As of July 2025, support for Razer Synapse 4 and the corresponding Chroma SDK is fixed. The basic RGB control is back to work with any compatible device. New features and more fixes will be added in the future.


**AIOChroma** is an API wrapper for communication with Razer Chroma devices.

Up till now, it is mostly used for the [custom Chroma integration for Home Assistant](https://github.com/Vaskivskyi/ha-chroma). But you are welcome to use it for your purposes, as well as suggest new features which you would like to use.

A short presentation of the features can be found in this [YouTube video](https://www.youtube.com/watch?v=ytdS9JUWSb4).

## Installation

Installation of the latest release is available from PyPI:

```
pip install aiochroma
```

## Usage

This section is still under development.

## Supported devices

This list provides only the models tested by me or other users.

Some of the devices might be in the group which you would not expect. This is not related to the integration but to the Chroma SDK.

<table>

<tr><th>Group</th><th>Devices</th></tr>

<tr><td>Chromalink</td><td>

`Chroma Addressable RGB Controller` (<a href="https://amzn.to/3WyMNzb" rel="nofollow sponsored" target="_blank">link*</a>)<br />
Mousepads: `Goliathus Extended Chroma` (<a href="https://amzn.to/3Gudkbl" rel="nofollow sponsored" target="_blank">link</a>)<br/>
Services: `AuraConnect`

</td></tr>

<tr><td>Headset</td><td>

`Kraken 7.1 V2` (<a href="https://amzn.to/3G78AqG" rel="nofollow sponsored" target="_blank">link</a>), `Kraken X USB` (<a href="https://amzn.to/3Z1QUWk" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Keyboard</td><td>

`BlackWidow Chroma` (<a href="https://amzn.to/3hWc7QU" rel="nofollow sponsored" target="_blank">link</a>), `BlackWidow Elite`(<a href="https://amzn.to/3NFzSJy" rel="nofollow sponsored" target="_blank">link</a>), `BlackWidow V3 Pro` (<a href="https://amzn.to/3i58M1Q" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Cynosa Chroma` (<a href="https://amzn.to/3VFbI2S" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Huntsman Elite` (<a href="https://amzn.to/3C8fhb1" rel="nofollow sponsored" target="_blank">link</a>), `Huntsman V2 Analog` (<a href="https://amzn.to/3YbKink" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Keypad</td><td>

`Tartarus V2` (<a href="https://amzn.to/3RUYVuq" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

<tr><td>Mouse</td><td>

`Basilisk` (<a href="https://amzn.to/3jDzfE4" rel="nofollow sponsored" target="_blank">link</a>), `Basilisk V3 Pro` (<a href="https://amzn.to/3IndSmK" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`DeathAdder V2 Pro` (<a href="https://amzn.to/3jEJBnl" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Mamba Tournament Edition` (<a href="https://amzn.to/3WCAguA" rel="nofollow sponsored" target="_blank">link</a>)<br/>
`Viper Ultimate` (<a href="https://amzn.to/3G5kRMu" rel="nofollow sponsored" target="_blank">link</a>) (+ `Mouse Dock`) (<a href="https://amzn.to/3YXCyWN" rel="nofollow sponsored" target="_blank">link</a>)
</td></tr>

<tr><td>Mousepad</td><td>

`Base Station V2 Chroma` (<a href="https://amzn.to/3x7NxjS" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Firefly V2` (<a href="https://amzn.to/3FYiAm0" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Monitor Stand Chroma` (<a href="https://amzn.to/4lpKKKr" rel="nofollow sponsored" target="_blank">link</a>)<br />
`Mouse Bungee V3 Chroma` (<a href="https://amzn.to/3ImsEbg" rel="nofollow sponsored" target="_blank">link</a>)

</td></tr>

</table>
* As an Amazon Associate I earn from qualifying purchases. Not like I ever got anything yet (:

## Support the development

This library is a free-time project. If you like it, you can support me by buying a coffee.

<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://asusrouter.vaskivskyi.com/BuyMeACoffee.png" alt="Buy Me A Coffee" style="height: 60px !important;"></a>
